==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/RETRY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour RETRY_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RETRY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="NEXTRETRY" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="REMAINING" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="manualretry" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RETRY_Type", propOrder = {
    "nextretry",
    "remaining"
})
public class RETRY_Type {

    @XmlElement(name = "NEXTRETRY")
    protected DATETIME nextretry;
    @XmlElement(name = "REMAINING")
    protected Long remaining;
    @XmlAttribute(name = "manualretry")
    protected Boolean manualretry;

    /**
     * Obtient la valeur de la propriété nextretry.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getNEXTRETRY() {
        return nextretry;
    }

    /**
     * Définit la valeur de la propriété nextretry.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setNEXTRETRY(DATETIME value) {
        this.nextretry = value;
    }

    /**
     * Obtient la valeur de la propriété remaining.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getREMAINING() {
        return remaining;
    }

    /**
     * Définit la valeur de la propriété remaining.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setREMAINING(Long value) {
        this.remaining = value;
    }

    /**
     * Obtient la valeur de la propriété manualretry.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isManualretry() {
        return manualretry;
    }

    /**
     * Définit la valeur de la propriété manualretry.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setManualretry(Boolean value) {
        this.manualretry = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RETRY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for RETRY_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RETRY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="NEXTRETRY" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="REMAINING" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="manualretry" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RETRY_Type", propOrder = {
    "nextretry",
    "remaining"
})
public class RETRY_Type {

    @XmlElement(name = "NEXTRETRY")
    protected DATETIME nextretry;
    @XmlElement(name = "REMAINING")
    protected Long remaining;
    @XmlAttribute(name = "manualretry")
    protected Boolean manualretry;

    /**
     * Gets the value of the nextretry property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getNEXTRETRY() {
        return nextretry;
    }

    /**
     * Sets the value of the nextretry property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setNEXTRETRY(DATETIME value) {
        this.nextretry = value;
    }

    /**
     * Gets the value of the remaining property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getREMAINING() {
        return remaining;
    }

    /**
     * Sets the value of the remaining property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setREMAINING(Long value) {
        this.remaining = value;
    }

    /**
     * Gets the value of the manualretry property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isManualretry() {
        return manualretry;
    }

    /**
     * Sets the value of the manualretry property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setManualretry(Boolean value) {
        this.manualretry = value;
    }

}
